@@ -1,5 +1,5 @@
 package Markdent::Dialect::Theory::BlockParser;
-$Markdent::Dialect::Theory::BlockParser::VERSION = '0.24';
+$Markdent::Dialect::Theory::BlockParser::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -345,7 +345,7 @@ sub _normalize_cell_count_and_alignments {
     # "left". We loop through all the rules and set alignments accordingly.
     my %alignments;
 
-    for my $row ( grep { defined } @rows ) {
+    for my $row ( grep {defined} @rows ) {
 
         # If we have one extra column and the final cell has a colspan > 1 it
         # means we misinterpreted a trailing divider as indicating that the
@@ -458,7 +458,7 @@ Markdent::Dialect::Theory::BlockParser - Block parser for Theory's proposed Mark
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -485,13 +485,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
