@@ -1,5 +1,5 @@
 package Markdent::Dialect::Theory::SpanParser;
-$Markdent::Dialect::Theory::SpanParser::VERSION = '0.24';
+$Markdent::Dialect::Theory::SpanParser::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -30,7 +30,7 @@ Markdent::Dialect::Theory::SpanParser - Span parser for Theory's proposed Markdo
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -50,13 +50,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
