@@ -1,5 +1,5 @@
 package Markdent::Handler::HTMLFilter;
-$Markdent::Handler::HTMLFilter::VERSION = '0.24';
+$Markdent::Handler::HTMLFilter::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -17,13 +17,13 @@ sub filter_event {
 
     return
         if grep { $event->isa( 'Markdent::Event::' . $_ ) }
-            qw(
-            HTMLBlock
-            HTMLComment
-            HTMLCommentBlock
-            HTMLTag
-            StartHTMLTag
-            EndHTMLTag
+        qw(
+        HTMLBlock
+        HTMLComment
+        HTMLCommentBlock
+        HTMLTag
+        StartHTMLTag
+        EndHTMLTag
     );
 
     $self->handler()->handle_event($event);
@@ -47,7 +47,7 @@ Markdent::Handler::HTMLFilter - Filters out HTML events from the event stream
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -84,13 +84,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
