@@ -1,5 +1,5 @@
 package Markdent::Handler::MinimalTree;
-$Markdent::Handler::MinimalTree::VERSION = '0.24';
+$Markdent::Handler::MinimalTree::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -476,7 +476,7 @@ Markdent::Handler::MinimalTree - A Markdent handler which builds a tree
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -510,13 +510,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
