@@ -1,5 +1,5 @@
 package Markdent::Parser::BlockParser;
-$Markdent::Parser::BlockParser::VERSION = '0.24';
+$Markdent::Parser::BlockParser::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -106,12 +106,11 @@ sub parse_document {
                 }
                 { ( $1 || q{} ) . $self->_hash_and_save_html($2) }egxm;
 
-
         # We need to treat <hr/> tags as blocks as well, but they don't have
         # an ending delimiter.
         ${$text} =~ s{
                  ( $BlockStart )
-                 (<hr\ */?>)
+                 (<hr.*\ */?>)
                 }
                 { ( $1 || q{} ) . $self->_hash_and_save_html($2) }egxm;
 
@@ -792,7 +791,7 @@ Markdent::Parser::BlockParser - Block parser for standard Markdown
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -826,13 +825,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
