@@ -1,5 +1,5 @@
 package Markdent::Role::Simple;
-$Markdent::Role::Simple::VERSION = '0.24';
+$Markdent::Role::Simple::VERSION = '0.25';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -13,7 +13,7 @@ requires 'markdown_to_html';
 around markdown_to_html => sub {
     my $orig = shift;
     my $self = shift;
-    my %p = @_;
+    my %p    = @_;
 
     # XXX - should warn eventually.
     $p{dialects} = delete $p{dialect}
@@ -23,11 +23,11 @@ around markdown_to_html => sub {
 };
 
 sub _parse_markdown {
-    my $self = shift;
-    my $markdown = shift;
-    my $dialects = shift;
+    my $self          = shift;
+    my $markdown      = shift;
+    my $dialects      = shift;
     my $handler_class = shift;
-    my $handler_p = shift;
+    my $handler_p     = shift;
 
     my $capture = q{};
     open my $fh, '>', \$capture
@@ -60,7 +60,7 @@ Markdent::Role::Simple - A role for simple markdown to html converter classes
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 DESCRIPTION
 
@@ -83,13 +83,9 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Jason McIntosh <jmac@appleseed-sc.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2015 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
